unit CustomerEditorForm;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, Vcl.ActnList, Vcl.StdCtrls,
  CommonUnit, Vcl.ExtCtrls, Vcl.DBCtrls, Vcl.Grids, Vcl.DBGrids, Data.DB,
  EchoModule,
  Aurelius.Drivers.Interfaces, Aurelius.Engine.ObjectManager, Aurelius.Bind.Dataset,
  Aurelius.Bind.BaseDataset;

type
  TfmCustomerEditor = class(TForm)
    btRefresh: TButton;
    DBNavigator1: TDBNavigator;
    DataSource1: TDataSource;
    AureliusDataset1: TAureliusDataset;
    AureliusDataset1Name: TStringField;
    DBGrid1: TDBGrid;
    btPush: TButton;
    btPull: TButton;
    cbAutomatic: TCheckBox;
    PushTimer: TTimer;
    PullTimer: TTimer;
    procedure FormDestroy(Sender: TObject);
    procedure acAutomaticPushPullExecute(Sender: TObject);
    procedure btPushClick(Sender: TObject);
    procedure btPullClick(Sender: TObject);
    procedure btRefreshClick(Sender: TObject);
    procedure PushTimerTimer(Sender: TObject);
    procedure PullTimerTimer(Sender: TObject);
  private
    FManager: TObjectManager;
    FModule: TdmEcho;
    procedure RefreshData;
  public
    constructor Create(AOwner: TComponent; AModule: TdmEcho); reintroduce;
  end;

implementation

{$R *.dfm}

{ TfmCustomerEditor }

procedure TfmCustomerEditor.acAutomaticPushPullExecute(Sender: TObject);
begin
  PullTimer.Enabled := cbAutomatic.Checked;
  PushTimer.Enabled := cbAutomatic.Checked;
  btPush.Visible := not PushTimer.Enabled;
  btPull.Visible := not PullTimer.Enabled;
end;

procedure TfmCustomerEditor.btRefreshClick(Sender: TObject);
begin
  RefreshData;
end;

procedure TfmCustomerEditor.btPushClick(Sender: TObject);
begin
  FModule.Push;
end;

procedure TfmCustomerEditor.btPullClick(Sender: TObject);
begin
  FModule.Pull;
end;

constructor TfmCustomerEditor.Create(AOwner: TComponent; AModule: TdmEcho);
begin
  inherited Create(AOwner);
  FModule := AModule;
  FManager := TObjectManager.Create(AModule.Echo.Pool.GetConnection);
  Caption := AModule.DBName;
  AureliusDataset1.Manager := FManager;
  RefreshData;
end;

procedure TfmCustomerEditor.FormDestroy(Sender: TObject);
begin
  AureliusDataset1.Close;
  FManager.Free;
end;

procedure TfmCustomerEditor.PullTimerTimer(Sender: TObject);
begin
  FModule.Pull;
end;

procedure TfmCustomerEditor.PushTimerTimer(Sender: TObject);
begin
  FModule.Push;
end;

procedure TfmCustomerEditor.RefreshData;
begin
  AureliusDataset1.Close;
  FManager.Clear;
//  AureliusDataset1.SetSourceCriteria(FManager.Find<TCustomer>);
  AureliusDataset1.Open;
end;

end.
